<div style="display:flex;align-items:center;justify-content:space-between;">
<h1 style="display:inline-block;">DoIt4U</h1>
<img src="logo.png" alt="alt text" width="50"/>
</div>

DoIt4U is a natural language hybrid Python programming framework based on OpenAI API. DoIt4U is a conceptual prototype and not intended for use in production environments.

## Installation

## Usage

## Example

## Contact





